@@ -11,6 +11,9 @@ class LabeledRadioButtonGroup(LabeledContainer):
    def getValueText(self):
       return self.getSmartWidget((self.getValue(), 0))["text"]
    
+   def reloadValue(self):
+      super().reloadValue()
+   
    def _inflateChildren(self):
       for child in self._baseContainerChildren:
          if "type" not in child:
